==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/structllarp_1_1net_1_1ip__header__le.md <==
---
title: llarp::net::ip_header_le

---

# llarp::net::ip_header_le



 [More...](#detailed-description)

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| unsigned int | **[ihl](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-ihl)**  |
| unsigned int | **[version](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-version)**  |
| uint8_t | **[tos](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-tos)**  |
| uint16_t | **[tot_len](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-tot-len)**  |
| uint16_t | **[id](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-id)**  |
| uint16_t | **[frag_off](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-frag-off)**  |
| uint8_t | **[ttl](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-ttl)**  |
| uint8_t | **[protocol](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-protocol)**  |
| uint16_t | **[check](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-check)**  |
| uint32_t | **[saddr](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-saddr)**  |
| uint32_t | **[daddr](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-daddr)**  |

## Detailed Description

```cpp
template <bool is_little_endian>
struct llarp::net::ip_header_le;
```

## Public Attributes Documentation

### variable ihl

```cpp
unsigned int ihl;
```


### variable version

```cpp
unsigned int version;
```


### variable tos

```cpp
uint8_t tos;
```


### variable tot_len

```cpp
uint16_t tot_len;
```


### variable id

```cpp
uint16_t id;
```


### variable frag_off

```cpp
uint16_t frag_off;
```


### variable ttl

```cpp
uint8_t ttl;
```


### variable protocol

```cpp
uint8_t protocol;
```


### variable check

```cpp
uint16_t check;
```


### variable saddr

```cpp
uint32_t saddr;
```


### variable daddr

```cpp
uint32_t daddr;
```


-------------------------------

Updated on 2022-05-31 at 02:25:19 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/structllarp_1_1net_1_1ip__header__le.md <==
---
title: llarp::net::ip_header_le

---

# llarp::net::ip_header_le





## Public Attributes

|                | Name           |
| -------------- | -------------- |
| uint8_t | **[ihl](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-ihl)**  |
| uint8_t | **[version](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-version)**  |
| uint8_t | **[tos](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-tos)**  |
| uint16_t | **[tot_len](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-tot-len)**  |
| uint16_t | **[id](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-id)**  |
| uint16_t | **[frag_off](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-frag-off)**  |
| uint8_t | **[ttl](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-ttl)**  |
| uint8_t | **[protocol](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-protocol)**  |
| uint16_t | **[check](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-check)**  |
| uint32_t | **[saddr](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-saddr)**  |
| uint32_t | **[daddr](Classes/structllarp_1_1net_1_1ip__header__le.md#variable-daddr)**  |

## Public Attributes Documentation

### variable ihl

```cpp
uint8_t ihl;
```


### variable version

```cpp
uint8_t version;
```


### variable tos

```cpp
uint8_t tos;
```


### variable tot_len

```cpp
uint16_t tot_len;
```


### variable id

```cpp
uint16_t id;
```


### variable frag_off

```cpp
uint16_t frag_off;
```


### variable ttl

```cpp
uint8_t ttl;
```


### variable protocol

```cpp
uint8_t protocol;
```


### variable check

```cpp
uint16_t check;
```


### variable saddr

```cpp
uint32_t saddr;
```


### variable daddr

```cpp
uint32_t daddr;
```


-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
